@@ -50,7 +50,8 @@ class Viewer():
     div_args : dict
         viewer div properties, including div_id, style, class, and
         background colour
-
+    rc_download : bool
+        Enables right-click download of model on webpage
     """
 
     def __init__(self, extra_div_args={}, extra_style_args={},
@@ -253,6 +254,43 @@ class Viewer():
 
 
 class Model():
+    """
+    Wrapper for 3Dmol.js GLModel class
+
+    Parameters
+    ----------
+    labels : list
+        atomic labels
+    coords : list
+        atomic coordinates in angstrom
+
+    Attributes
+    ----------
+    objects : list[str], optional
+        List of molvis objects added to viewer callback function whose
+        __repr__ will be called via str()
+        e.g. `core.Model`
+        ```
+        ms1 = core.Model.from_xyz(xyz_file)
+        viewer_1 = core.Viewer(objects=[ms1])
+        ```
+    div_id : str
+        viewer div id string
+    height : str
+        viewer div height as string
+    width : str
+        viewer div width as string
+    position : str
+        viewer div position as string
+    style : dict
+        viewer div style, contains height, width and position. Can
+        be overwritten completely.
+    div_args : dict
+        viewer div properties, including div_id, style, class, and
+        background colour
+    rc_download : bool
+        Enables right-click download of model on webpage
+    """
     def __init__(self, labels, coords, **kwargs) -> None:
 
         self.coords = coords
@@ -287,7 +325,7 @@ class Model():
             for label in self.labels_nn
         ]
         self.atom_opacities = 1.
-        self.atom_radii = 1.
+        self.atom_radii = .5
 
         self.extra_styles = []
 
@@ -393,8 +431,10 @@ class Model():
 
     def __repr__(self) -> str:
 
+        # Create atom specification
         atoms_spec = self.gen_atoms_spec()
 
+        # Create model and add atoms to model
         model_str = "        var {} = viewer.addModel();\n".format(
             self.model_js_var
         )
@@ -402,11 +442,14 @@ class Model():
             self.model_js_var, atoms_spec
         )
 
+        # Generate style dictionary
         set_styles = self.gen_set_style()
 
+        # Merge in other style if present
         if len(self.extra_styles):
             set_styles = self.merge_styles(set_styles, self.extra_styles)
 
+        # Print style dictionary
         for set_style in set_styles:
             model_str += "            {}.setStyle(".format(
                 self.model_js_var
@@ -438,7 +481,7 @@ class Model():
 
         Returns
         -------
-        list:
+        list
             dictionaries, one per atom, describing atom label, position, and
             indices of other atoms bonded to that atom
 
@@ -463,6 +506,14 @@ class Model():
         return molecule
 
     def gen_set_style(self):
+        """
+        Creates list of style dictionaries, one per atom, for 3dmol.js model
+
+        Returns
+        -------
+            list
+                style dictionaries, one per atom
+        """
 
         set_style = [
             [
@@ -480,7 +531,23 @@ class Model():
 
     @staticmethod
     def merge_styles(style_1, style_2):
+        """
+        Combines two lists of style dictionaries atom by atom
+        This allows styles of a single atom to be combined, e.g.
+        sphere + stick are combined to give a ball and stick representation
 
+        Parameters
+        ----------
+        style_1 : list[dict]
+            List of style dictionaries generated by `gen_set_style`
+        style_2 : list[dict]
+            List of style dictionaries generated by `gen_set_style`
+        
+        Returns
+        -------
+        list
+            style dictionaries, one per atom
+        """
         new_style = [
             [
                 s1[0],
@@ -493,7 +560,7 @@ class Model():
 
 class HtmlPage():
     """
-    Objct defining a single html file/page with given elements
+    Object defining a single html file/page with given elements
 
     Parameters
     ----------
